@@ -10,7 +10,7 @@
 
 */
 
-#include "../../uwsgi.h"
+#include <uwsgi.h>
 
 extern struct uwsgi_server uwsgi;
 
